#include <iostream>
#include <cassert>
#include <vector>
#include <queue>
using namespace std;

vector<int> decompose(int M, int N) {
    // assuming 1 <= M <= 2^(N-1)-2
    if (M+1 == 1<<(N-1)) return vector<int>(1,N-1);
    vector<int> answer;
    for (int k=N-2; k>=1; --k) {
        int cur = (1<<k)-1;
        if (M == 2*cur) { answer.push_back(k); answer.push_back(k); return answer; }
        if (M == cur) { answer.push_back(k); return answer; }
        if (M > cur) { answer.push_back(k); M -= cur; }
    }
    assert(false);
}

class Cave {
    public:
    int N;
    vector< vector<int> > tunnels; // tunnels[z][x] has bit y set iff there is a tunnel from x to y with the letter 'a'+z
    
    Cave(int N, int D) : N(N) { 
        while (D <= (1<<(N-1))) --N;
        tunnels.resize(3, vector<int>(N,0) ); 
        // generate the basic cave pattern
        tunnels[0][0] |= 1;
        tunnels[1][0] |= 1;
        tunnels[2][1] |= 1;
        for (int n=0; n<N-1; ++n) {
            tunnels[0][n+1] |= 1<<n;
            tunnels[1][n+1] |= 1<<n;
        }
        for (int n=0; n<N; ++n) {
            tunnels[1][n] |= 1<<(N-1);
        }
        // add 'c' tunnels to increase the number of reachable DFA states if needed
        if (D == 1<<N) { tunnels[2][N-1] |= 1<<(N-1); return; }
        int remains = D - (1<<(N-1)) - 1;
        if (remains == 0) return;
        vector<int> add = decompose(remains,N);
        bool third_case = (add.size()>1 && add[ add.size()-1 ] == add[ add.size()-2 ]);
        if (third_case) add.pop_back();
        bool fourth_case = third_case && add.size()==N-2;
        for (unsigned i=0; i<add.size(); ++i) for (int j=0; j<N-1-add[i]; ++j) tunnels[2][N-1-i] |= 1<<(N-2-j);
        if (third_case) for (int j=0; j<=N-1-add.back(); ++j) tunnels[2][N-1-add.size()] |= 1<<(N-1-j);
        if (fourth_case) { tunnels[2][1] &= ~1; for (int j=1; j<=N-1; ++j) tunnels[2][1] |= 1<<j; }
    }
};

int main() {
    int T; cin >> T;
    while (T--) {
        int N, D; cin >> N >> D;
        cerr << N << " " << D << endl;
        if (D > (1<<N)) { cout << "-1\n"; continue; }
        Cave C(N,D);
        vector<int> X, Y, Z;
        for (int s=0; s<3; ++s) for (int n=0; n<N; ++n) for (int i=0; i<N; ++i) if (C.tunnels[s][n] & 1<<i) { X.push_back(n); Y.push_back(i); Z.push_back(s); }
        cout << X.size() << endl;
        for (unsigned i=0; i<X.size(); ++i) cout << X[i] << " " << Y[i] << " " << char('a'+Z[i]) << "\n";
    }
}
